/****************************************************************************
** Meta object code from reading C++ file 'khangman.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/khangman-17.04.3/src/khangman.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'khangman.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KHangMan_t {
    QByteArrayData data[59];
    char stringdata0[832];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KHangMan_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KHangMan_t qt_meta_stringdata_KHangMan = {
    {
QT_MOC_LITERAL(0, 0, 8), // "KHangMan"
QT_MOC_LITERAL(1, 9, 13), // "signalSetWins"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 4), // "wins"
QT_MOC_LITERAL(4, 29, 15), // "signalSetLosses"
QT_MOC_LITERAL(5, 45, 6), // "losses"
QT_MOC_LITERAL(6, 52, 18), // "resolveTimeChanged"
QT_MOC_LITERAL(7, 71, 19), // "soundEnabledChanged"
QT_MOC_LITERAL(8, 91, 22), // "currentLanguageChanged"
QT_MOC_LITERAL(9, 114, 22), // "currentCategoryChanged"
QT_MOC_LITERAL(10, 137, 18), // "currentWordChanged"
QT_MOC_LITERAL(11, 156, 18), // "currentHintChanged"
QT_MOC_LITERAL(12, 175, 16), // "languagesChanged"
QT_MOC_LITERAL(13, 192, 17), // "categoriesChanged"
QT_MOC_LITERAL(14, 210, 13), // "themesChanged"
QT_MOC_LITERAL(15, 224, 19), // "currentThemeChanged"
QT_MOC_LITERAL(16, 244, 15), // "winCountChanged"
QT_MOC_LITERAL(17, 260, 16), // "lossCountChanged"
QT_MOC_LITERAL(18, 277, 29), // "scoreMultiplyingFactorChanged"
QT_MOC_LITERAL(19, 307, 15), // "netScoreChanged"
QT_MOC_LITERAL(20, 323, 18), // "setCurrentLanguage"
QT_MOC_LITERAL(21, 342, 5), // "index"
QT_MOC_LITERAL(22, 348, 18), // "setCurrentCategory"
QT_MOC_LITERAL(23, 367, 15), // "setCurrentTheme"
QT_MOC_LITERAL(24, 383, 20), // "slotDownloadNewStuff"
QT_MOC_LITERAL(25, 404, 8), // "readFile"
QT_MOC_LITERAL(26, 413, 8), // "nextWord"
QT_MOC_LITERAL(27, 422, 11), // "setWinCount"
QT_MOC_LITERAL(28, 434, 5), // "count"
QT_MOC_LITERAL(29, 440, 12), // "setLossCount"
QT_MOC_LITERAL(30, 453, 25), // "setScoreMultiplyingFactor"
QT_MOC_LITERAL(31, 479, 6), // "factor"
QT_MOC_LITERAL(32, 486, 14), // "replaceLetters"
QT_MOC_LITERAL(33, 501, 10), // "charString"
QT_MOC_LITERAL(34, 512, 17), // "showAboutKHangMan"
QT_MOC_LITERAL(35, 530, 12), // "showAboutKDE"
QT_MOC_LITERAL(36, 543, 12), // "showHandbook"
QT_MOC_LITERAL(37, 556, 11), // "currentWord"
QT_MOC_LITERAL(38, 568, 14), // "getCurrentHint"
QT_MOC_LITERAL(39, 583, 8), // "alphabet"
QT_MOC_LITERAL(40, 592, 13), // "languageNames"
QT_MOC_LITERAL(41, 606, 12), // "containsChar"
QT_MOC_LITERAL(42, 619, 8), // "original"
QT_MOC_LITERAL(43, 628, 10), // "isResolved"
QT_MOC_LITERAL(44, 639, 17), // "revealCurrentWord"
QT_MOC_LITERAL(45, 657, 11), // "resolveTime"
QT_MOC_LITERAL(46, 669, 12), // "soundEnabled"
QT_MOC_LITERAL(47, 682, 15), // "currentLanguage"
QT_MOC_LITERAL(48, 698, 9), // "languages"
QT_MOC_LITERAL(49, 708, 15), // "currentCategory"
QT_MOC_LITERAL(50, 724, 10), // "categories"
QT_MOC_LITERAL(51, 735, 12), // "currentTheme"
QT_MOC_LITERAL(52, 748, 6), // "themes"
QT_MOC_LITERAL(53, 755, 13), // "backgroundUrl"
QT_MOC_LITERAL(54, 769, 11), // "currentHint"
QT_MOC_LITERAL(55, 781, 8), // "winCount"
QT_MOC_LITERAL(56, 790, 9), // "lossCount"
QT_MOC_LITERAL(57, 800, 22), // "scoreMultiplyingFactor"
QT_MOC_LITERAL(58, 823, 8) // "netScore"

    },
    "KHangMan\0signalSetWins\0\0wins\0"
    "signalSetLosses\0losses\0resolveTimeChanged\0"
    "soundEnabledChanged\0currentLanguageChanged\0"
    "currentCategoryChanged\0currentWordChanged\0"
    "currentHintChanged\0languagesChanged\0"
    "categoriesChanged\0themesChanged\0"
    "currentThemeChanged\0winCountChanged\0"
    "lossCountChanged\0scoreMultiplyingFactorChanged\0"
    "netScoreChanged\0setCurrentLanguage\0"
    "index\0setCurrentCategory\0setCurrentTheme\0"
    "slotDownloadNewStuff\0readFile\0nextWord\0"
    "setWinCount\0count\0setLossCount\0"
    "setScoreMultiplyingFactor\0factor\0"
    "replaceLetters\0charString\0showAboutKHangMan\0"
    "showAboutKDE\0showHandbook\0currentWord\0"
    "getCurrentHint\0alphabet\0languageNames\0"
    "containsChar\0original\0isResolved\0"
    "revealCurrentWord\0resolveTime\0"
    "soundEnabled\0currentLanguage\0languages\0"
    "currentCategory\0categories\0currentTheme\0"
    "themes\0backgroundUrl\0currentHint\0"
    "winCount\0lossCount\0scoreMultiplyingFactor\0"
    "netScore"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KHangMan[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      36,   14, // methods
      16,  250, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      16,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  194,    2, 0x06 /* Public */,
       4,    1,  197,    2, 0x06 /* Public */,
       6,    0,  200,    2, 0x06 /* Public */,
       7,    0,  201,    2, 0x06 /* Public */,
       8,    0,  202,    2, 0x06 /* Public */,
       9,    0,  203,    2, 0x06 /* Public */,
      10,    0,  204,    2, 0x06 /* Public */,
      11,    0,  205,    2, 0x06 /* Public */,
      12,    0,  206,    2, 0x06 /* Public */,
      13,    0,  207,    2, 0x06 /* Public */,
      14,    0,  208,    2, 0x06 /* Public */,
      15,    0,  209,    2, 0x06 /* Public */,
      16,    0,  210,    2, 0x06 /* Public */,
      17,    0,  211,    2, 0x06 /* Public */,
      18,    0,  212,    2, 0x06 /* Public */,
      19,    0,  213,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      20,    1,  214,    2, 0x0a /* Public */,
      22,    1,  217,    2, 0x0a /* Public */,
      23,    1,  220,    2, 0x0a /* Public */,
      24,    0,  223,    2, 0x0a /* Public */,
      25,    0,  224,    2, 0x0a /* Public */,
      26,    0,  225,    2, 0x0a /* Public */,
      27,    1,  226,    2, 0x0a /* Public */,
      29,    1,  229,    2, 0x0a /* Public */,
      30,    1,  232,    2, 0x0a /* Public */,
      32,    1,  235,    2, 0x0a /* Public */,
      34,    0,  238,    2, 0x0a /* Public */,
      35,    0,  239,    2, 0x0a /* Public */,
      36,    0,  240,    2, 0x0a /* Public */,

 // methods: name, argc, parameters, tag, flags
      37,    0,  241,    2, 0x02 /* Public */,
      38,    0,  242,    2, 0x02 /* Public */,
      39,    0,  243,    2, 0x02 /* Public */,
      40,    0,  244,    2, 0x02 /* Public */,
      41,    1,  245,    2, 0x02 /* Public */,
      43,    0,  248,    2, 0x02 /* Public */,
      44,    0,  249,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   28,
    QMetaType::Void, QMetaType::Int,   28,
    QMetaType::Void, QMetaType::Int,   31,
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::QStringList,
    QMetaType::QString,
    QMetaType::QStringList,
    QMetaType::QStringList,
    QMetaType::Bool, QMetaType::QString,   42,
    QMetaType::Bool,
    QMetaType::Void,

 // properties: name, type, flags
      45, QMetaType::Int, 0x00495103,
      46, QMetaType::Bool, 0x00495103,
      47, QMetaType::Int, 0x00495103,
      48, QMetaType::QStringList, 0x00495001,
      49, QMetaType::Int, 0x00495103,
      50, QMetaType::QStringList, 0x00495001,
      51, QMetaType::Int, 0x00495103,
      52, QMetaType::QStringList, 0x00495001,
      53, QMetaType::QString, 0x00495001,
      37, QMetaType::QStringList, 0x00495001,
      54, QMetaType::QString, 0x00495001,
      39, QMetaType::QStringList, 0x00495001,
      55, QMetaType::Int, 0x00495103,
      56, QMetaType::Int, 0x00495103,
      57, QMetaType::Int, 0x00495103,
      58, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       2,
       3,
       4,
       8,
       5,
       9,
      11,
      10,
      11,
       6,
       7,
       4,
      12,
      13,
      14,
      15,

       0        // eod
};

void KHangMan::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KHangMan *_t = static_cast<KHangMan *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalSetWins((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->signalSetLosses((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->resolveTimeChanged(); break;
        case 3: _t->soundEnabledChanged(); break;
        case 4: _t->currentLanguageChanged(); break;
        case 5: _t->currentCategoryChanged(); break;
        case 6: _t->currentWordChanged(); break;
        case 7: _t->currentHintChanged(); break;
        case 8: _t->languagesChanged(); break;
        case 9: _t->categoriesChanged(); break;
        case 10: _t->themesChanged(); break;
        case 11: _t->currentThemeChanged(); break;
        case 12: _t->winCountChanged(); break;
        case 13: _t->lossCountChanged(); break;
        case 14: _t->scoreMultiplyingFactorChanged(); break;
        case 15: _t->netScoreChanged(); break;
        case 16: _t->setCurrentLanguage((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->setCurrentCategory((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->setCurrentTheme((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->slotDownloadNewStuff(); break;
        case 20: _t->readFile(); break;
        case 21: _t->nextWord(); break;
        case 22: _t->setWinCount((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->setLossCount((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->setScoreMultiplyingFactor((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->replaceLetters((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 26: _t->showAboutKHangMan(); break;
        case 27: _t->showAboutKDE(); break;
        case 28: _t->showHandbook(); break;
        case 29: { QStringList _r = _t->currentWord();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 30: { QString _r = _t->getCurrentHint();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 31: { QStringList _r = _t->alphabet();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 32: { QStringList _r = _t->languageNames();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = _r; }  break;
        case 33: { bool _r = _t->containsChar((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 34: { bool _r = _t->isResolved();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 35: _t->revealCurrentWord(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KHangMan::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::signalSetWins)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::signalSetLosses)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::resolveTimeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::soundEnabledChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::currentLanguageChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::currentCategoryChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::currentWordChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::currentHintChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::languagesChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::categoriesChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::themesChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::currentThemeChanged)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::winCountChanged)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::lossCountChanged)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::scoreMultiplyingFactorChanged)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (KHangMan::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KHangMan::netScoreChanged)) {
                *result = 15;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KHangMan *_t = static_cast<KHangMan *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->resolveTime(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->soundEnabled(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->currentLanguage(); break;
        case 3: *reinterpret_cast< QStringList*>(_v) = _t->languages(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->currentCategory(); break;
        case 5: *reinterpret_cast< QStringList*>(_v) = _t->categories(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->currentTheme(); break;
        case 7: *reinterpret_cast< QStringList*>(_v) = _t->themes(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->backgroundUrl(); break;
        case 9: *reinterpret_cast< QStringList*>(_v) = _t->currentWord(); break;
        case 10: *reinterpret_cast< QString*>(_v) = _t->getCurrentHint(); break;
        case 11: *reinterpret_cast< QStringList*>(_v) = _t->alphabet(); break;
        case 12: *reinterpret_cast< int*>(_v) = _t->winCount(); break;
        case 13: *reinterpret_cast< int*>(_v) = _t->lossCount(); break;
        case 14: *reinterpret_cast< int*>(_v) = _t->scoreMultiplyingFactor(); break;
        case 15: *reinterpret_cast< int*>(_v) = _t->netScore(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KHangMan *_t = static_cast<KHangMan *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setResolveTime(*reinterpret_cast< int*>(_v)); break;
        case 1: _t->setSoundEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setCurrentLanguage(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setCurrentCategory(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setCurrentTheme(*reinterpret_cast< int*>(_v)); break;
        case 12: _t->setWinCount(*reinterpret_cast< int*>(_v)); break;
        case 13: _t->setLossCount(*reinterpret_cast< int*>(_v)); break;
        case 14: _t->setScoreMultiplyingFactor(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KHangMan::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_KHangMan.data,
      qt_meta_data_KHangMan,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KHangMan::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHangMan::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KHangMan.stringdata0))
        return static_cast<void*>(const_cast< KHangMan*>(this));
    return QMainWindow::qt_metacast(_clname);
}

int KHangMan::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 36;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 16;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KHangMan::signalSetWins(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KHangMan::signalSetLosses(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KHangMan::resolveTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}

// SIGNAL 3
void KHangMan::soundEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void KHangMan::currentLanguageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}

// SIGNAL 5
void KHangMan::currentCategoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, Q_NULLPTR);
}

// SIGNAL 6
void KHangMan::currentWordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}

// SIGNAL 7
void KHangMan::currentHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, Q_NULLPTR);
}

// SIGNAL 8
void KHangMan::languagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, Q_NULLPTR);
}

// SIGNAL 9
void KHangMan::categoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, Q_NULLPTR);
}

// SIGNAL 10
void KHangMan::themesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, Q_NULLPTR);
}

// SIGNAL 11
void KHangMan::currentThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, Q_NULLPTR);
}

// SIGNAL 12
void KHangMan::winCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, Q_NULLPTR);
}

// SIGNAL 13
void KHangMan::lossCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, Q_NULLPTR);
}

// SIGNAL 14
void KHangMan::scoreMultiplyingFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, Q_NULLPTR);
}

// SIGNAL 15
void KHangMan::netScoreChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
